@@ -13,7 +13,7 @@ import subprocess
 from fastcodedog.context.context import ctx_instance
 
 
-def write_python_file(path, content):
+def write_python_file(path, content, repalce_async=True):
     """
     写入python文件
     :param path:
@@ -29,7 +29,8 @@ def write_python_file(path, content):
     # 临时版本，把异步支持去掉,把文件中的 `async def` 替换为 `def`
     with open(path, 'r+', encoding='utf-8') as f:
         content = f.read()
-        content = content.replace('async def ', 'def ')
+        if repalce_async:
+            content = content.replace('async def ', 'def ')
         f.seek(0)
         f.write(content)
         f.truncate()
