@@ -12,6 +12,7 @@ from fastcodedog.context.setting.extend_app import ExtendApp
 from fastcodedog.context.setting.listen import Listen
 from fastcodedog.context.setting.project import Project
 from fastcodedog.context.setting.source_directory import SourceDirectory
+from fastcodedog.context.setting.tenant import Tenant
 from fastcodedog.util.find_file import find
 from fastcodedog.util.singleton import Singleton
 
@@ -21,6 +22,7 @@ class Context(ContextBase):
     def __init__(self):
         super().__init__()
         self.project = Project()
+        self.tenant = Tenant()
         self.config = Config()
         self.source_directory = SourceDirectory()
         self.oauth2 = OAuth2()
@@ -35,6 +37,7 @@ class Context(ContextBase):
     def load(self, json_file, with_prepared_source=True):
         data = json5.load(open(json_file, 'r', encoding='utf-8'))
         self.project.load(data['project'])
+        self.tenant.load(data['tenant'])
         self.config.load(data['config'])
         self.source_directory.load(data['source_directory'])
         self.oauth2.load(data['oauth2'])
@@ -88,5 +91,11 @@ class Context(ContextBase):
                 self.apis[api.module] = {}
             self.apis[api.module][api.name] = api
 
+    def get_tenant_model(self):
+        for module in self.models.values():
+            for model in module.values():
+                if model.table_name == self.tenant.foreign_table_code:
+                    return model
+        return None
 
 ctx_instance = Context()
