@@ -17,8 +17,8 @@ from fastcodedog.util.case_converter import camel_to_snake
 class Main(File):
     def __init__(self):
         super().__init__('main',
-                         file_path=LocationFinder.get_path('main'),
-                         package=LocationFinder.get_package('main'))
+                         file_path=LocationFinder.get_path('main', 'app'),
+                         package=LocationFinder.get_package('main', 'app'))
         self._init_blocks()
 
     def _init_blocks(self):
@@ -28,8 +28,8 @@ class Main(File):
         self.blocks.append(Text(f"""app.add_middleware(ApiLoggingMiddleware)""",
                                 possible_imports=Import('ApiLoggingMiddleware', ApiLogging().package)))
         self.blocks.append(Text('# 确保sqlalchemy的日志和配置一致'))
-        self.blocks.append(Text("logging.getLogger('sqlalchemy.engine').setLevel(logging_config['level'])",
-                                possible_imports=['import logging', 'from review.config.config import logging_config']))
+        self.blocks.append(Text("logging.getLogger('sqlalchemy.engine').setLevel(log_level)",
+                                possible_imports=['import logging', 'from review.config.config import log_level']))
         self._init_swagger()
         self._init_sqlalchemy_error_handler()
         # 异常捕捉定义和配置之间加空行
