@@ -32,6 +32,9 @@ OAuth2.REDIS_URL = 'redis://localhost:6379/oauth2'""")
             Variable('app', value='FastAPI()', possible_imports='from fastapi import FastAPI'))
         self.blocks.append(Variable('oauth2_scheme', value=f"OAuth2PasswordBearer(tokenUrl='{self.token_url}')",
                                     possible_imports='from fastapi.security import OAuth2PasswordBearer'))
+        self.blocks.append(Text("""if redis_url:
+    OAuth2.REDIS_URL = redis_url
+        """, possible_imports=Import('redis_url', Config().package)))
         self._init_login()
         self._init_remove_and_refresh()
         self._init_read_me()
