@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from fastcodedog.generation.commonfiles.utilfiles.api_logging import ApiLogging
 from fastcodedog.generation.commonfiles.utilfiles.case_converter import CaseConverter
 from fastcodedog.generation.commonfiles.utilfiles.log import Log
 
@@ -6,3 +7,4 @@ from fastcodedog.generation.commonfiles.utilfiles.log import Log
 def generate_common_files():
     CaseConverter().save()
     Log().save()
+    ApiLogging().save()
