@@ -21,8 +21,7 @@ class Log(File):
         self.blocks.append(Variable('logger', value='get_logger()'))
 
     def get_get_logger(self):
-        function = Function('get_logger', possible_imports=['import logging', 'from concurrent_log_handler import ConcurrentRotatingFileHandler',
-                                   Import('logging_config', Config().package)])
+        function = Function('get_logger')
         content =f"""global logger_
 if logger_:
     return logger_
@@ -30,20 +29,21 @@ if logger_:
 logger_ = logging.getLogger()
 if logger_.hasHandlers():
     logger_.handlers.clear()
-logger_.setLevel(logging_config['level'])
+logger_.setLevel(log_level)
 
-rotating_file_handler = ConcurrentRotatingFileHandler(logging_config['filename'], mode='a', maxBytes=int(logging_config['max_bytes']),
-                              backupCount=int(logging_config['backup_count']), encoding=logging_config['encoding'])
-rotating_file_handler.setLevel(logging_config['level'])
-rotating_file_handler.setFormatter(logging.Formatter(logging_config['format'], datefmt=logging_config['datefmt']))
+rotating_file_handler = ConcurrentRotatingFileHandler(log_filename, mode='a', maxBytes=int(log_max_bytes),
+                                                      backupCount=int(log_backup_count), encoding=log_encoding)
+rotating_file_handler.setLevel(log_level)
+rotating_file_handler.setFormatter(logging.Formatter(log_format, datefmt=log_datefmt))
 logger_.addHandler(rotating_file_handler)
 
-if logging_config['console']:
+if log_console:
     enable_console_log(logger_)
 
 return logger_
         """
-        function.blocks.append(Text(content))
+        function.blocks.append(Text(content, possible_imports=['import logging', 'from concurrent_log_handler import ConcurrentRotatingFileHandler',
+                                   Import('logging_config', Config().package), 'from review.config.config import log_filename','from review.config.config import log_level','from review.config.config import log_encoding','from review.config.config import log_datefmt','from review.config.config import log_format','from review.config.config import log_max_bytes','from review.config.config import log_backup_count','from review.config.config import log_console']))
         return function
 
     def get_enable_console_log(self):
@@ -51,9 +51,9 @@ return logger_
                                                                     Import('logging_config', Config().package)])
         function.params['logger_'] = Function.Parameter('logger_', nullable=False)
         content = f"""console_handler = logging.StreamHandler()
-console_handler.setLevel(logging_config['level'])
-console_handler.setFormatter(logging.Formatter(logging_config['format']))
+console_handler.setLevel(log_level)
+console_handler.setFormatter(logging.Formatter(log_format))
 logger_.addHandler(console_handler)
 """
-        function.blocks.append(Text(content))
+        function.blocks.append(Text(content, possible_imports=['from review.config.config import log_filename','from review.config.config import log_level','from review.config.config import log_encoding','from review.config.config import log_datefmt','from review.config.config import log_format','from review.config.config import log_max_bytes','from review.config.config import log_backup_count','from review.config.config import log_console']))
         return function
