@@ -9,8 +9,8 @@ from fastcodedog.generation.base.variable import Variable
 class Base(File):
     def __init__(self):
         super().__init__('base',
-                         file_path=os.path.join(ctx_instance.project.directory, 'model', 'base.py'),
-                         package=f'{ctx_instance.project.package}.model.base',
+                         file_path=os.path.join(ctx_instance.project.directory, 'model', 'base_model.py'),
+                         package=f'{ctx_instance.project.package}.model.base_model',
                          context={}, comment='基类。一个工程内应该只有一个Base基类')
         self.base = Variable('Base', value='declarative_base()',
                              possible_imports='from sqlalchemy.orm import declarative_base')
