@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from fastcodedog.context.model.model import Model as ModelContext
+from fastcodedog.generation.model.copy_method import CopyMethod
 from fastcodedog.generation.base.class_type import ClassType
 from fastcodedog.generation.base.line_break import LineBreak
 from fastcodedog.generation.base.location_finder import LocationFinder
@@ -29,4 +30,6 @@ class Model(ClassType):
 
         for additional_method in context.additional_methods.values():
             self.blocks.append(AdditionalMethod(additional_method))
+        for copy_method in context.copy_methods.values():
+            self.blocks.append(CopyMethod(copy_method))
         self.add_possible_imports(Import('Base', LocationFinder.get_package('Base')))
